@@ -26,13 +26,24 @@
 namespace na = neutral_analytical;
 namespace necsim
 {
-    Metacommunity::Metacommunity() : seed(0), job_type(0), parameters_checked(false),
+    Metacommunity::Metacommunity() : seed(0), task(0), parameters_checked(false),
                                      species_abundances_handler(make_unique<SimulatedSpeciesAbundancesHandler>()),
-                                     random(make_shared<RNGController>()), metacommunity_tree(make_unique<Tree>())
+                                     random(make_shared<RNGController>()), metacommunity_tree()
     {
 
     }
 
+    Metacommunity &Metacommunity::operator=(const Metacommunity &m)
+    {
+        seed = m.seed;
+        task = m.task;
+        parameters_checked = m.parameters_checked;
+        species_abundances_handler = make_unique<SimulatedSpeciesAbundancesHandler>();
+        random = m.random;
+        metacommunity_tree = m.metacommunity_tree;
+        return *this;
+    }
+
     void Metacommunity::setCommunityParameters(shared_ptr<MetacommunityParameters> metacommunity_parameters)
     {
         current_metacommunity_parameters = std::move(metacommunity_parameters);
@@ -60,14 +71,33 @@ namespace necsim
                 throw FatalException("Cannot read simulation metacommunity parameters as database is null pointer.");
             }
             // Now do the same for times
-            string sql_call = "SELECT seed, job_type from SIMULATION_PARAMETERS";
-            auto stmt = database->prepare(sql_call);
-            database->step();
-            seed = sqlite3_column_int64(stmt->stmt, 0);
-            random->setSeed(seed);
-            job_type = sqlite3_column_int64(stmt->stmt, 1);
-            database->finalise();
-            parameters_checked = true;
+
+            exception err;
+
+            for(auto &i: vector<string>{"task", "job_type"})
+            {
+                try
+                {
+                    string sql_call = "SELECT seed, " + i + " from SIMULATION_PARAMETERS";
+                    auto stmt = database->prepare(sql_call);
+                    database->step();
+                    seed = sqlite3_column_int64(stmt->stmt, 0);
+                    random->setSeed(seed);
+                    task = sqlite3_column_int64(stmt->stmt, 1);
+                    database->finalise();
+                    parameters_checked = true;
+                    break;
+                }
+                catch(exception &e)
+                {
+                    err = e;
+                }
+            }
+            if(!parameters_checked)
+            {
+                throw err;
+            }
+
         }
     }
 
@@ -108,23 +138,27 @@ namespace necsim
             seed = 1073741823;
         }
         temp_parameters->setMetacommunityParameters(current_metacommunity_parameters->metacommunity_size,
-                                                    current_metacommunity_parameters->speciation_rate, seed, job_type);
+                                                    current_metacommunity_parameters->speciation_rate,
+                                                    seed,
+                                                    task);
         // Dispose of any previous Tree object and create a new one
-        metacommunity_tree = make_unique<Tree>();
-        metacommunity_tree->internalSetup(temp_parameters);
+        metacommunity_tree = Tree();
+        metacommunity_tree.internalSetup(temp_parameters);
         // Run our simulation and calculate the species abundance distribution (as this is all that needs to be stored).
-        if(!metacommunity_tree->runSimulation())
+        if(!metacommunity_tree.runSimulation())
         {
             throw FatalException("Completion of the non-spatial coalescence simulation "
                                  "to create the metacommunity did not finish in time.");
         }
-        metacommunity_tree->applySpecRateInternal(current_metacommunity_parameters->speciation_rate, 0.0);
+        metacommunity_tree.applySpecRateInternal(current_metacommunity_parameters->speciation_rate, 0.0);
         // species_abundances now contains the number of individuals per species
         // Make it cumulative to increase the speed of indexing using binary search.
         species_abundances_handler = make_unique<SimulatedSpeciesAbundancesHandler>();
-        species_abundances_handler->setup(random, current_metacommunity_parameters->metacommunity_size,
-                                          current_metacommunity_parameters->speciation_rate, nodes->size());
-        auto tmp_species_abundances = metacommunity_tree->getSpeciesAbundances();
+        species_abundances_handler->setup(random,
+                                          current_metacommunity_parameters->metacommunity_size,
+                                          current_metacommunity_parameters->speciation_rate,
+                                          nodes->size());
+        auto tmp_species_abundances = metacommunity_tree.getSpeciesAbundances();
         if(tmp_species_abundances->empty())
         {
             throw FatalException("Simulated species abundance list is empty. Please report this bug.");
@@ -136,6 +170,11 @@ namespace necsim
 #endif //DEBUG
     }
 
+    void Metacommunity::applyNoOutput(shared_ptr<SpecSimParameters> sp)
+    {
+        Community::applyNoOutput(sp);
+    }
+
     void Metacommunity::applyNoOutput(shared_ptr<SpecSimParameters> sp, shared_ptr<vector<TreeNode>> tree_data)
     {
 #ifdef DEBUG
@@ -179,8 +218,10 @@ namespace necsim
     {
         species_abundances_handler.reset();
         species_abundances_handler = make_unique<AnalyticalSpeciesAbundancesHandler>();
-        species_abundances_handler->setup(random, current_metacommunity_parameters->metacommunity_size,
-                                          current_metacommunity_parameters->speciation_rate, nodes->size());
+        species_abundances_handler->setup(random,
+                                          current_metacommunity_parameters->metacommunity_size,
+                                          current_metacommunity_parameters->speciation_rate,
+                                          nodes->size());
     }
 
     void Metacommunity::readSAD()
@@ -191,8 +232,10 @@ namespace necsim
                 current_metacommunity_parameters->external_reference);
         species_abundances_handler.reset();
         species_abundances_handler = make_unique<SimulatedSpeciesAbundancesHandler>();
-        species_abundances_handler->setup(random, current_metacommunity_parameters->metacommunity_size,
-                                          current_metacommunity_parameters->speciation_rate, nodes->size());
+        species_abundances_handler->setup(random,
+                                          current_metacommunity_parameters->metacommunity_size,
+                                          current_metacommunity_parameters->speciation_rate,
+                                          nodes->size());
         species_abundances_handler->setAbundanceList(sad);
     }
 
