@@ -37,19 +37,21 @@ namespace necsim
     class Metacommunity : public virtual Community
     {
     protected:
-        // Simulation seed and job_type (read from the output database or set to 1)
+        // Simulation seed and task (read from the output database or set to 1)
         unsigned long seed;
-        unsigned long job_type;
+        unsigned long task;
         bool parameters_checked;
         unique_ptr<SpeciesAbundancesHandler> species_abundances_handler;
         shared_ptr<RNGController> random;
-        unique_ptr<Tree> metacommunity_tree;
+        Tree metacommunity_tree;
     public:
 
         Metacommunity();
 
         ~Metacommunity() override = default;
 
+
+        Metacommunity& operator=(const Metacommunity& m);
         /**
          * @brief Sets the parameters for the metacommunity
          * @param community_size_in the number of individuals in the metacommunity
@@ -61,7 +63,7 @@ namespace necsim
         void setCommunityParameters(shared_ptr<MetacommunityParameters> metacommunity_parameters);
 
         /**
-         * @brief Gets the seed and the job_type from the SIMULATION_PARAMETERS database and stores them in the relevant
+         * @brief Gets the seed and the task from the SIMULATION_PARAMETERS database and stores them in the relevant
          * variables.
          *
          * @note Should only be called once, and will have no effect if called multiple times.
@@ -84,6 +86,13 @@ namespace necsim
          */
         void createMetacommunityNSENeutralModel();
 
+        /**
+         * @brief Applies the speciation parameters to the completed simulation, including running the spatially implicit
+         * for the metacommunity structure, but doesn't write the output
+         * @param sp speciation parameters to apply, including speciation rate, times and spatial sampling procedure.
+         */
+        void applyNoOutput(shared_ptr<SpecSimParameters> sp) override;
+
         /**
          * @brief Applies the speciation parameters to the completed simulation, including running the spatially implicit
          * for the metacommunity structure, but doesn't write the output
