@@ -24,21 +24,16 @@ namespace necsim
 {
     class ProtractedSpatialTree : public virtual SpatialTree, public virtual ProtractedTree
     {
-        //    /**
-        //     * @brief Calculates the speciation probability from the random number, speciation rate and number of generations a
-        //     * lineage has existed for.
-        //     * @param random_number the generated random number from 0-1
-        //     * @param speciation_rate the speciation rate to be applied
-        //     * @param no_generations the number of generations a lineage has existed for
-        //     * @return if true, speciation has occured
-        //     */
-        //    bool calcSpeciation(const long double &random_number,
-        //                        const long double &speciation_rate,
-        //                        const unsigned long &no_generations) override
-        //    {
-        //        return ProtractedTree::calcSpeciation(random_number, speciation_rate, no_generations);
-        //    }
+    public:
+        ProtractedSpatialTree();
+        ProtractedSpatialTree(ProtractedSpatialTree &&other) noexcept;
+        ProtractedSpatialTree(const ProtractedSpatialTree &other) noexcept ;
 
+        ProtractedSpatialTree &operator=(const ProtractedSpatialTree &other) noexcept;
+
+        ProtractedSpatialTree &operator=(ProtractedSpatialTree &&other) noexcept;
     };
+
+
 }
 #endif //SPECIATIONCOUNTER_PROTRACTEDSPATIALTREE_H
