@@ -194,6 +194,14 @@ namespace necsim
             metacommunity_parameters.clear();
         }
 
+        /**
+         * @brief Wipes the protracted parameters
+         */
+        void wipeProtractedParameters()
+        {
+            protracted_parameters.clear();
+        }
+
         /**
          * @brief Adds an additional time to the times vector.
          * @param time a time to calculate speciation rates at
